from Deadline.Events import DeadlineEventListener
from Deadline.Scripting import RepositoryUtils

def GetDeadlineEventListener():
    """This is the function that Deadline calls to get an instance of the
    main DeadlineEventListener class.
    """
    return DevelopingEvent()

def CleanupDeadlineEventListener(deadlinePlugin):
    """This is the function that Deadline calls when the event plugin is
    no longer in use so that it can get cleaned up.
    """
    deadlinePlugin.Cleanup()

class DevelopingEvent(DeadlineEventListener):
    """This is the main DeadlineEventListener class for DevelopingEvent"""
    def __init__(self):
        # Set up the event callbacks here
        super().__init__() # Required in Deadline 10.3 and later.
        self.OnJobSubmittedCallback += self.OnJobSubmitted
        self.OnJobFinishedCallback += self.OnJobFinished

    def Cleanup(self):
        del self.OnJobSubmittedCallback
        del self.OnJobFinishedCallback

    def OnJobSubmitted(self, job):
        print(f"The job being submitted is named {job.JobName}")

    def OnJobFinished(self, job):
        print(f"The job that finished is named {job.JobName}")


# To ease troubleshooting, let's add a __main__ method so we can call our event without having to submit and complete jobs

# Run the __main__ function you have to use deadlinecommand -executescript DevelopingEvent.py
# __main__ will not be run when the event is run through the event system.

def __main__():
    
# Our event functions (OnJobSubmitted and OnJobFinished) take self and a job object as arguemnts
    
# First we need to get a job object. Right click a job in the Monitor -> Scripts -> Copy Job ID
    
    test_job_id = "6621468c28182aaeb0741a3f" # replace this with what you've gotten

    test_job = RepositoryUtils.GetJob(test_job_id, True)

    print(f"The test job is named {test_job.JobName}") # Prove that we haven't used the wrong Job ID before testing

    my_event = DevelopingEvent()

    # Call our event
    my_event.OnJobFinished(test_job)
